# QWED Comprehensive Test Audit Report

**Generated:** 2025-12-02 03:22:53

**Duration:** 1.2 seconds

---

## Executive Summary

- **Total Tests:** 6
- **Passed:** 3 ✅
- **Failed:** 3 ❌
- **Pass Rate:** 50.0%

**Status:** ⚠️ NEEDS IMPROVEMENT

---

## Results by Priority

| Priority | Total | Passed | Failed | Pass Rate |
|----------|-------|--------|--------|-----------|
| ❌ CRITICAL | 4 | 2 | 2 | 50.0% |
| ❌ HIGH | 2 | 1 | 1 | 50.0% |
| ❌ MEDIUM | 0 | 0 | 0 | 0.0% |


## Results by Engine

| Engine | Total | Passed | Failed | Pass Rate |
|--------|-------|--------|--------|-----------|
| ❌ stats | 6 | 3 | 3 | 50.0% |


## ❌ Failed Tests (3)

### Detect os module in statistical code
- **Engine:** stats
- **Priority:** HIGH
- **Test ID:** `STATS_IMP_001`
- **Expected:** CRITICAL - os.system() detected
- **Timestamp:** 2025-12-02T03:22:52.789067

### Detect subprocess in stats code
- **Engine:** stats
- **Priority:** CRITICAL
- **Test ID:** `STATS_IMP_002`
- **Expected:** CRITICAL - subprocess usage
- **Timestamp:** 2025-12-02T03:22:52.979267

### Detect DataFrame.eval() injection risk
- **Engine:** stats
- **Priority:** CRITICAL
- **Test ID:** `STATS_SEC_001`
- **Error:** 'str' object has no attribute 'get'
- **Expected:** N/A
- **Timestamp:** 2025-12-02T03:22:53.323187

## ✅ Passed Tests (3)


### STATS Engine (3 tests)
- ✅ Detect pickle.loads() RCE risk (174ms)
- ✅ Detect exec() in analysis code (179ms)
- ✅ Allow safe pandas operations (190ms)

---

*Generated by QWED Advanced Testing Framework*
